@@ -3,13 +3,14 @@ from django.test import TestCase
 from django.test import Client
 from django.core.urlresolvers import reverse
 from django.test.testcases import urlsplit, urlunsplit
+from django.conf import settings
 
 
 class ViewTest(TestCase):
     '''
     TestCase for view testing
     '''
-                    
+                        
     def setUp(self):
         """This method is automatically called by the Django test framework."""
         self.client = Client()
@@ -20,7 +21,7 @@ class ViewTest(TestCase):
         self.failUnlessEqual(response.status_code, status)
         return response
     
-    def check_login_required(self, url_name, login_url = '/accounts/login/', kwargs=None, current_app=None):
+    def check_login_required(self, url_name, kwargs=None, current_app=None):
         """ Check if response is a redirect to login page (ignoring GET variables) """
         response = self.client.get(reverse(url_name, kwargs=kwargs, current_app=current_app))
         
@@ -28,5 +29,5 @@ class ViewTest(TestCase):
         scheme, netloc, path, query, fragment = urlsplit(response['Location'])
         response['Location'] = urlunsplit(('http', 'testserver', path, None, None))
                 
-        self.assertRedirects(response, login_url)
+        self.assertRedirects(response, getattr(settings, 'LOGIN_URL', '/accounts/login/'))
         return response
\ No newline at end of file
